@@ -11,8 +11,9 @@ class GitLabGroups(GitLabCore):
         return self._make_requests_to_api("groups", data=data, method='POST', expected_codes=201)
 
     def delete_group(self, group_name):
+        # 404 means that the group does not exist anymore, so let's accept it for idempotency
         return self._make_requests_to_api("groups/%s", group_name, method='DELETE',
-                                          expected_codes=[200, 202, 204])
+                                          expected_codes=[200, 202, 204, 404])
 
     def get_group(self, name):
         return self._make_requests_to_api("groups/%s", name)
@@ -58,26 +59,14 @@ class GitLabGroups(GitLabCore):
         self._make_requests_to_api("groups/%s", project_and_group_name, 'PUT', group_settings)
 
     def post_group_secret_variable(self, group, secret_variable):
-        # secret_variable has to be like this:
-        # {
-        #     'key': key,
-        #     'value': value,
-        #     "variable_type": "env_var",
-        #     "protected": false
-        # }
-        # ..as documented at: https://docs.gitlab.com/ce/api/build_variables.html#create-variable
+        # secret_variable has to be like documented at:
+        # https://docs.gitlab.com/ee/api/group_level_variables.html#create-variable
         self._make_requests_to_api("groups/%s/variables", group, 'POST', secret_variable,
                                    expected_codes=201)
 
     def put_group_secret_variable(self, group, secret_variable):
-        # secret_variable has to be like this:
-        # {
-        #     'key': key,
-        #     'value': value,
-        #     "variable_type": "env_var",
-        #     "protected": false
-        # }
-        # ..as documented at: https://docs.gitlab.com/ce/api/build_variables.html#update-variable
+        # secret_variable has to be like documented at:
+        # https://docs.gitlab.com/ee/api/group_level_variables.html#create-variable
         self._make_requests_to_api("groups/%s/variables/%s", (group, secret_variable['key']),
                                    'PUT', secret_variable)
 
@@ -85,4 +74,8 @@ class GitLabGroups(GitLabCore):
         return self._make_requests_to_api("groups/%s/variables/%s", (group, secret_variable_key))['value']
 
     def get_group_secret_variables(self, group):
-        return self._make_requests_to_api("groups/%s/variables", group)
\ No newline at end of file
+        return self._make_requests_to_api("groups/%s/variables", group)
+
+    def delete_group_secret_variable(self, group, secret_variable):
+        self._make_requests_to_api("groups/%s/variables/%s", (group, secret_variable), 'DELETE',
+                                   expected_codes=[200, 202, 204, 404])
