@@ -14,8 +14,9 @@ class GitLabProjects(GitLabCore):
         return self._make_requests_to_api("projects", data=data, method='POST', expected_codes=201)
 
     def delete_project(self, project_and_group_name):
+        # 404 means that the project does not exist anymore, so let's accept it for idempotency
         return self._make_requests_to_api("projects/%s", project_and_group_name, method='DELETE',
-                                          expected_codes=[202, 204])
+                                          expected_codes=[202, 204, 404])
 
     def get_all_projects(self):
         """
@@ -46,22 +47,14 @@ class GitLabProjects(GitLabCore):
         return self._make_requests_to_api("projects/%s/deploy_keys/%s", (project_and_group_name, id), 'GET')
 
     def post_secret_variable(self, project_and_group_name, secret_variable):
-        # secret_variable has to be like this:
-        # {
-        #     'key': key,
-        #     'value': value,
-        # }
-        # ..as documented at: https://docs.gitlab.com/ce/api/build_variables.html#create-variable
+        # secret_variable has to be like documented at:
+        # https://docs.gitlab.com/ee/api/project_level_variables.html#create-variable
         self._make_requests_to_api("projects/%s/variables", project_and_group_name, 'POST', secret_variable,
                                    expected_codes=201)
 
     def put_secret_variable(self, project_and_group_name, secret_variable):
-        # secret_variable has to be like this:
-        # {
-        #     'key': key,
-        #     'value': value,
-        # }
-        # ..as documented at: https://docs.gitlab.com/ce/api/build_variables.html#update-variable
+        # secret_variable has to be like documented at:
+        # https://docs.gitlab.com/ce/api/build_variables.html#update-variable
         self._make_requests_to_api("projects/%s/variables/%s", (project_and_group_name, secret_variable['key']),
                                    'PUT', secret_variable)
 
